==> jc-1.4.0.tar.gz: gnu/java/util/prefs/MemoryBasedFactory.h <==
// public class gnu.java.util.prefs.MemoryBasedFactory

// class file dependencies
// @dep_class 9a8838970c87ee87 gnu_java_util_prefs_MemoryBasedFactory
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_util_prefs_MemoryBasedFactory_H_
#define _JC_gnu_java_util_prefs_MemoryBasedFactory_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_prefs_Preferences$object;

// Typedefs
typedef struct _jc_gnu_java_util_prefs_MemoryBasedFactory$sub_refs	_jc_gnu_java_util_prefs_MemoryBasedFactory$sub_refs;
typedef struct _jc_gnu_java_util_prefs_MemoryBasedFactory$sub_nonrefs	_jc_gnu_java_util_prefs_MemoryBasedFactory$sub_nonrefs;
typedef struct _jc_gnu_java_util_prefs_MemoryBasedFactory$refs	_jc_gnu_java_util_prefs_MemoryBasedFactory$refs;
typedef struct _jc_gnu_java_util_prefs_MemoryBasedFactory$nonrefs	_jc_gnu_java_util_prefs_MemoryBasedFactory$nonrefs;
typedef struct _jc_gnu_java_util_prefs_MemoryBasedFactory$object	_jc_gnu_java_util_prefs_MemoryBasedFactory$object;

typedef struct _jc_gnu_java_util_prefs_MemoryBasedFactory$fields_struct	_jc_gnu_java_util_prefs_MemoryBasedFactory$fields_struct;
typedef const struct _jc_gnu_java_util_prefs_MemoryBasedFactory$vmethods	_jc_gnu_java_util_prefs_MemoryBasedFactory$vmethods;
typedef const struct _jc_gnu_java_util_prefs_MemoryBasedFactory$vtable	_jc_gnu_java_util_prefs_MemoryBasedFactory$vtable;
typedef const struct _jc_gnu_java_util_prefs_MemoryBasedFactory$vtype	_jc_gnu_java_util_prefs_MemoryBasedFactory$vtype;

// Class fields structure
struct _jc_gnu_java_util_prefs_MemoryBasedFactory$fields_struct {
	struct _jc_java_util_prefs_Preferences$object	*systemPreferences;
	struct _jc_java_util_prefs_Preferences$object	*userPreferences;
};
extern _jc_gnu_java_util_prefs_MemoryBasedFactory$fields_struct _jc_gnu_java_util_prefs_MemoryBasedFactory$class_fields;

// Constructors
extern void _jc_gnu_java_util_prefs_MemoryBasedFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_util_prefs_MemoryBasedFactory$object *);

// Virtual methods
extern struct _jc_java_util_prefs_Preferences$object *_jc_gnu_java_util_prefs_MemoryBasedFactory$method$systemRoot$bf0a6df2e99738a0(_jc_env *, struct _jc_gnu_java_util_prefs_MemoryBasedFactory$object *);
extern struct _jc_java_util_prefs_Preferences$object *_jc_gnu_java_util_prefs_MemoryBasedFactory$method$userRoot$b327c33849f7289d(_jc_env *, struct _jc_gnu_java_util_prefs_MemoryBasedFactory$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_util_prefs_MemoryBasedFactory$method_info$systemRoot$bf0a6df2e99738a0;
extern _jc_method _jc_gnu_java_util_prefs_MemoryBasedFactory$method_info$userRoot$b327c33849f7289d;

// Static methods
extern void _jc_gnu_java_util_prefs_MemoryBasedFactory$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_gnu_java_util_prefs_MemoryBasedFactory$vmethods {
	struct _jc_java_util_prefs_Preferences$object	*(*systemRoot$bf0a6df2e99738a0)(_jc_env *, struct _jc_gnu_java_util_prefs_MemoryBasedFactory$object *);
	struct _jc_java_util_prefs_Preferences$object	*(*userRoot$b327c33849f7289d)(_jc_env *, struct _jc_gnu_java_util_prefs_MemoryBasedFactory$object *);
};

// Vtable
struct _jc_gnu_java_util_prefs_MemoryBasedFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_util_prefs_MemoryBasedFactory$vmethods	gnu_java_util_prefs_MemoryBasedFactory;
};

// Vtype
struct _jc_gnu_java_util_prefs_MemoryBasedFactory$vtype {
	_jc_type			type;
	_jc_gnu_java_util_prefs_MemoryBasedFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_util_prefs_MemoryBasedFactory$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_util_prefs_MemoryBasedFactory$refs {
    _jc_gnu_java_util_prefs_MemoryBasedFactory$sub_refs	gnu_java_util_prefs_MemoryBasedFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_util_prefs_MemoryBasedFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_util_prefs_MemoryBasedFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_util_prefs_MemoryBasedFactory$sub_nonrefs	gnu_java_util_prefs_MemoryBasedFactory;
};

// Object instance structure
struct _jc_gnu_java_util_prefs_MemoryBasedFactory$object {
	_jc_gnu_java_util_prefs_MemoryBasedFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_util_prefs_MemoryBasedFactory$vtype	*vtype;
	_jc_gnu_java_util_prefs_MemoryBasedFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_util_prefs_MemoryBasedFactory$vtype _jc_gnu_java_util_prefs_MemoryBasedFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_util_prefs_MemoryBasedFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_util_prefs_MemoryBasedFactory$class_object;

#endif	/* _JC_gnu_java_util_prefs_MemoryBasedFactory_H_ */

==> jc-1.4.6.tar.gz: gnu/java/util/prefs/MemoryBasedFactory.h <==
// public class gnu.java.util.prefs.MemoryBasedFactory

// class file dependencies
// @dep_class 9a8838970c87ee87 gnu_java_util_prefs_MemoryBasedFactory
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_util_prefs_MemoryBasedFactory_H_
#define _JC_gnu_java_util_prefs_MemoryBasedFactory_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_prefs_Preferences$object;

// Typedefs
typedef struct _jc_gnu_java_util_prefs_MemoryBasedFactory$sub_refs	_jc_gnu_java_util_prefs_MemoryBasedFactory$sub_refs;
typedef struct _jc_gnu_java_util_prefs_MemoryBasedFactory$sub_nonrefs	_jc_gnu_java_util_prefs_MemoryBasedFactory$sub_nonrefs;
typedef struct _jc_gnu_java_util_prefs_MemoryBasedFactory$refs	_jc_gnu_java_util_prefs_MemoryBasedFactory$refs;
typedef struct _jc_gnu_java_util_prefs_MemoryBasedFactory$nonrefs	_jc_gnu_java_util_prefs_MemoryBasedFactory$nonrefs;
typedef struct _jc_gnu_java_util_prefs_MemoryBasedFactory$object	_jc_gnu_java_util_prefs_MemoryBasedFactory$object;

typedef struct _jc_gnu_java_util_prefs_MemoryBasedFactory$fields_struct	_jc_gnu_java_util_prefs_MemoryBasedFactory$fields_struct;
typedef const struct _jc_gnu_java_util_prefs_MemoryBasedFactory$vmethods	_jc_gnu_java_util_prefs_MemoryBasedFactory$vmethods;
typedef const struct _jc_gnu_java_util_prefs_MemoryBasedFactory$vtable	_jc_gnu_java_util_prefs_MemoryBasedFactory$vtable;
typedef const struct _jc_gnu_java_util_prefs_MemoryBasedFactory$vtype	_jc_gnu_java_util_prefs_MemoryBasedFactory$vtype;

// Class fields structure
struct _jc_gnu_java_util_prefs_MemoryBasedFactory$fields_struct {
	struct _jc_java_util_prefs_Preferences$object	*systemPreferences;
	struct _jc_java_util_prefs_Preferences$object	*userPreferences;
};
extern _jc_gnu_java_util_prefs_MemoryBasedFactory$fields_struct _jc_gnu_java_util_prefs_MemoryBasedFactory$class_fields;

// Constructors
extern void _jc_gnu_java_util_prefs_MemoryBasedFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_util_prefs_MemoryBasedFactory$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_util_prefs_Preferences$object *_jc_gnu_java_util_prefs_MemoryBasedFactory$method$systemRoot$bf0a6df2e99738a0(_jc_env *, struct _jc_gnu_java_util_prefs_MemoryBasedFactory$object *) _JC_JCNI_ATTR;
extern struct _jc_java_util_prefs_Preferences$object *_jc_gnu_java_util_prefs_MemoryBasedFactory$method$userRoot$b327c33849f7289d(_jc_env *, struct _jc_gnu_java_util_prefs_MemoryBasedFactory$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_util_prefs_MemoryBasedFactory$method_info$systemRoot$bf0a6df2e99738a0;
extern _jc_method _jc_gnu_java_util_prefs_MemoryBasedFactory$method_info$userRoot$b327c33849f7289d;

// Static methods
extern void _jc_gnu_java_util_prefs_MemoryBasedFactory$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_util_prefs_MemoryBasedFactory$vmethods {
	struct _jc_java_util_prefs_Preferences$object	*(*systemRoot$bf0a6df2e99738a0)(_jc_env *, struct _jc_gnu_java_util_prefs_MemoryBasedFactory$object *) _JC_JCNI_ATTR;
	struct _jc_java_util_prefs_Preferences$object	*(*userRoot$b327c33849f7289d)(_jc_env *, struct _jc_gnu_java_util_prefs_MemoryBasedFactory$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_util_prefs_MemoryBasedFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_util_prefs_MemoryBasedFactory$vmethods	gnu_java_util_prefs_MemoryBasedFactory;
};

// Vtype
struct _jc_gnu_java_util_prefs_MemoryBasedFactory$vtype {
	_jc_type			type;
	_jc_gnu_java_util_prefs_MemoryBasedFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_util_prefs_MemoryBasedFactory$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_util_prefs_MemoryBasedFactory$refs {
    _jc_gnu_java_util_prefs_MemoryBasedFactory$sub_refs	gnu_java_util_prefs_MemoryBasedFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_util_prefs_MemoryBasedFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_util_prefs_MemoryBasedFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_util_prefs_MemoryBasedFactory$sub_nonrefs	gnu_java_util_prefs_MemoryBasedFactory;
};

// Object instance structure
struct _jc_gnu_java_util_prefs_MemoryBasedFactory$object {
	_jc_gnu_java_util_prefs_MemoryBasedFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_util_prefs_MemoryBasedFactory$vtype	*vtype;
	_jc_gnu_java_util_prefs_MemoryBasedFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_util_prefs_MemoryBasedFactory$vtype _jc_gnu_java_util_prefs_MemoryBasedFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_util_prefs_MemoryBasedFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_util_prefs_MemoryBasedFactory$class_object;

#endif	/* _JC_gnu_java_util_prefs_MemoryBasedFactory_H_ */
